@@ -6,10 +6,11 @@
 import {describe, test, expect} from '@gsa/testing';
 import Tag from 'gmp/models/tag';
 import {testModel} from 'gmp/models/testing';
-
-testModel(Tag, 'tag');
+import {type ApiType} from 'gmp/utils/entity-type';
 
 describe('Tag model tests', () => {
+  testModel(Tag, 'tag');
+
   test('should use defaults', () => {
     const tag = new Tag();
     expect(tag.resourceType).toBeUndefined();
@@ -24,31 +25,27 @@ describe('Tag model tests', () => {
     expect(tag.value).toBeUndefined();
   });
 
-  test('should parse resources', () => {
-    const tag = Tag.fromElement({
-      resources: {
-        type: 'task',
-        count: {
-          total: 42,
+  test.each([
+    {resourceType: 'task', entityType: 'task'},
+    {resourceType: 'report_format', entityType: 'reportformat'},
+    {resourceType: 'os', entityType: 'operatingsystem'},
+    {resourceType: 'config', entityType: 'scanconfig'},
+  ])(
+    'should parse resource type $resourceType',
+    ({resourceType, entityType}) => {
+      const tag = Tag.fromElement({
+        resources: {
+          type: resourceType as ApiType,
+          count: {
+            total: 42,
+          },
         },
-      },
-    });
+      });
 
-    expect(tag.resourceType).toEqual('task');
-    expect(tag.resourceCount).toEqual(42);
-
-    const tag2 = Tag.fromElement({
-      resources: {
-        type: 'report_format',
-        count: {
-          total: 42,
-        },
-      },
-    });
-
-    expect(tag2.resourceType).toEqual('reportformat');
-    expect(tag2.resourceCount).toEqual(42);
-  });
+      expect(tag.resourceType).toEqual(entityType);
+      expect(tag.resourceCount).toEqual(42);
+    },
+  );
 
   test('should parse value', () => {
     const tag = Tag.fromElement({value: 'foo'});
