@@ -4,14 +4,7 @@
  */
 
 import {describe, test, expect} from '@gsa/testing';
-import Task, {
-  HOSTS_ORDERING_RANDOM,
-  HOSTS_ORDERING_REVERSE,
-  HOSTS_ORDERING_SEQUENTIAL,
-  TASK_STATUS,
-  type TaskStatus,
-  USAGE_TYPE,
-} from 'gmp/models/task';
+import Task, {TASK_STATUS, type TaskStatus, USAGE_TYPE} from 'gmp/models/task';
 import {testModel} from 'gmp/models/testing';
 import {parseDate, parseDuration} from 'gmp/parser';
 
@@ -28,7 +21,6 @@ describe('Task Model parse tests', () => {
     expect(task.average_duration).toBeUndefined();
     expect(task.config).toBeUndefined();
     expect(task.current_report).toBeUndefined();
-    expect(task.hosts_ordering).toBeUndefined();
     expect(task.in_assets).toBeUndefined();
     expect(task.last_report).toBeUndefined();
     expect(task.max_checks).toBeUndefined();
@@ -50,6 +42,7 @@ describe('Task Model parse tests', () => {
     expect(task.usageType).toEqual(USAGE_TYPE.scan);
     expect(task.acceptInvalidCerts).toBeUndefined();
     expect(task.registryAllowInsecure).toBeUndefined();
+    expect(task.csAllowFailedRetrieval).toBeUndefined();
   });
 
   test('should parse empty element', () => {
@@ -62,7 +55,6 @@ describe('Task Model parse tests', () => {
     expect(task.average_duration).toBeUndefined();
     expect(task.config).toBeUndefined();
     expect(task.current_report).toBeUndefined();
-    expect(task.hosts_ordering).toBeUndefined();
     expect(task.in_assets).toBeUndefined();
     expect(task.last_report).toBeUndefined();
     expect(task.max_checks).toBeUndefined();
@@ -84,21 +76,7 @@ describe('Task Model parse tests', () => {
     expect(task.usageType).toEqual(USAGE_TYPE.scan);
     expect(task.acceptInvalidCerts).toBeUndefined();
     expect(task.registryAllowInsecure).toBeUndefined();
-  });
-
-  test('should parse hosts ordering', () => {
-    // @ts-expect-error
-    const task = Task.fromElement({hosts_ordering: 'foo'});
-    expect(task.hosts_ordering).toBeUndefined();
-
-    const task2 = Task.fromElement({hosts_ordering: HOSTS_ORDERING_RANDOM});
-    expect(task2.hosts_ordering).toEqual(HOSTS_ORDERING_RANDOM);
-
-    const task3 = Task.fromElement({hosts_ordering: HOSTS_ORDERING_REVERSE});
-    expect(task3.hosts_ordering).toEqual(HOSTS_ORDERING_REVERSE);
-
-    const task4 = Task.fromElement({hosts_ordering: HOSTS_ORDERING_SEQUENTIAL});
-    expect(task4.hosts_ordering).toEqual(HOSTS_ORDERING_SEQUENTIAL);
+    expect(task.csAllowFailedRetrieval).toBeUndefined();
   });
 
   test('should parse last report', () => {
@@ -543,6 +521,42 @@ describe('Task Model parse tests', () => {
       });
     }).toThrow("Task.parseElement: usage_type must be 'scan'");
   });
+
+  test('should parse csAllowFailedRetrieval', () => {
+    const task1 = Task.fromElement({
+      _id: 't1',
+      preferences: {
+        preference: [
+          {
+            scanner_name: 'cs_allow_failed_retrieval',
+            value: 1,
+          },
+        ],
+      },
+    });
+    expect(task1.id).toEqual('t1');
+    expect(task1.csAllowFailedRetrieval).toEqual(true);
+
+    const task2 = Task.fromElement({
+      _id: 't2',
+      preferences: {
+        preference: [
+          {
+            scanner_name: 'cs_allow_failed_retrieval',
+            value: 0,
+          },
+        ],
+      },
+    });
+    expect(task2.id).toEqual('t2');
+    expect(task2.csAllowFailedRetrieval).toEqual(false);
+
+    const task3 = Task.fromElement({
+      _id: 't3',
+    });
+    expect(task3.id).toEqual('t3');
+    expect(task3.csAllowFailedRetrieval).toBeUndefined();
+  });
 });
 
 describe(`Task Model methods tests`, () => {
