@@ -4,16 +4,17 @@
  */
 
 import {useCallback} from 'react';
-import {FileInput} from '@greenbone/opensight-ui-components-mantinev7';
+import type {FileInputProps} from '@mantine/core';
+import {FileInput} from '@greenbone/ui-lib';
 import {isDefined} from 'gmp/utils/identity';
+import useTranslation from 'web/hooks/useTranslation';
 
-interface FileFieldProps
-  extends React.ComponentPropsWithoutRef<typeof FileInput> {
+interface FileFieldProps extends Omit<FileInputProps, 'label' | 'onChange'> {
   disabled?: boolean;
   grow?: number | string;
   name?: string;
   title?: string;
-  onChange?: (file: File, name?: string) => void;
+  onChange?: (file: File | undefined, name?: string) => void;
 }
 
 const FileField = ({
@@ -21,13 +22,15 @@ const FileField = ({
   grow,
   name,
   title,
+  value,
   onChange,
   ...props
 }: FileFieldProps) => {
+  const [_] = useTranslation();
   const handleChange = useCallback(
     (file: File) => {
       if (!disabled && isDefined(onChange)) {
-        onChange(file, name);
+        onChange(file ?? undefined, name);
       }
     },
     [onChange, disabled, name],
@@ -37,10 +40,13 @@ const FileField = ({
     <FileInput
       data-testid="file-input"
       {...props}
+      clearButtonProps={{title: _('Clear input')}}
+      clearable={true}
       disabled={disabled}
       label={title}
       name={name}
       styles={{root: {flexGrow: grow}}}
+      value={value ?? null}
       onChange={handleChange}
     />
   );
