@@ -16,7 +16,7 @@ import CollectionCounts from 'gmp/collection/collection-counts';
 import Filter from 'gmp/models/filter';
 import Role from 'gmp/models/role';
 import {YES_VALUE, NO_VALUE} from 'gmp/parser';
-import {currentSettingsDefaultResponse} from 'web/pages/__mocks__/current-settings';
+import {currentSettingsDefaultResponse} from 'web/pages/__fixtures__/current-settings';
 import RoleListPage from 'web/pages/roles/RoleListPage';
 import RoleListPageToolBarIcons from 'web/pages/roles/RoleListPageToolBarIcons';
 import {entitiesLoadingActions} from 'web/store/entities/roles';
