@@ -15,7 +15,6 @@ import Layout from 'web/components/layout/Layout';
 import DetailsLink from 'web/components/link/DetailsLink';
 import Loading from 'web/components/loading/Loading';
 import useTranslation from 'web/hooks/useTranslation';
-import {MAX_RESOURCES} from 'web/pages/tags/TagsComponent';
 import {
   createLoadEntities,
   createEntitiesLoadingActions,
@@ -25,6 +24,8 @@ import compose from 'web/utils/Compose';
 import PropTypes from 'web/utils/PropTypes';
 import withGmp from 'web/utils/withGmp';
 
+const MAX_RESOURCES = 40; // concerns listing in "Assigned Resources" tab
+
 const Spacer = styled.div`
   height: 12px;
 `;
